@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------- #
-# Copyright 2019-2023, OpenNebula Systems S.L.                               #
+# Copyright 2019-2025, OpenNebula Systems S.L.                               #
 #                                                                            #
 # Licensed under the OpenNebula Software License                             #
 # (the "License"); you may not use this file except in compliance with       #
@@ -15,16 +15,13 @@
 # governing permissions and  limitations under the License.                  #
 # -------------------------------------------------------------------------- #
 
-require "rexml/document"
-include REXML
-
 module Migrator
     def db_version
-        "2.9.90"
+        "4.3.90"
     end
 
     def one_version
-        "OpenNebula 2.9.90"
+        "OpenNebula 4.3.90"
     end
 
     def up
