@@ -79,6 +79,18 @@ module Aws::EC2
       data[:spread_level]
     end
 
+    # Reserved for future use.
+    # @return [String]
+    def linked_group_id
+      data[:linked_group_id]
+    end
+
+    # The service provider that manages the Placement Group.
+    # @return [Types::OperatorResponse]
+    def operator
+      data[:operator]
+    end
+
     # @!endgroup
 
     # @return [Client]
@@ -601,15 +613,16 @@ module Aws::EC2
     #
     #   * `platform-details` - The platform (`Linux/UNIX` \| `Red Hat BYOL
     #     Linux` \| ` Red Hat Enterprise Linux` \| `Red Hat Enterprise Linux
-    #     with HA` \| `Red Hat Enterprise Linux with SQL Server Standard and
-    #     HA` \| `Red Hat Enterprise Linux with SQL Server Enterprise and HA`
-    #     \| `Red Hat Enterprise Linux with SQL Server Standard` \| `Red Hat
-    #     Enterprise Linux with SQL Server Web` \| `Red Hat Enterprise Linux
-    #     with SQL Server Enterprise` \| `SQL Server Enterprise` \| `SQL
-    #     Server Standard` \| `SQL Server Web` \| `SUSE Linux` \| `Ubuntu Pro`
-    #     \| `Windows` \| `Windows BYOL` \| `Windows with SQL Server
-    #     Enterprise` \| `Windows with SQL Server Standard` \| `Windows with
-    #     SQL Server Web`).
+    #     with HA` \| `Red Hat Enterprise Linux with High Availability` \|
+    #     `Red Hat Enterprise Linux with SQL Server Standard and HA` \| `Red
+    #     Hat Enterprise Linux with SQL Server Enterprise and HA` \| `Red Hat
+    #     Enterprise Linux with SQL Server Standard` \| `Red Hat Enterprise
+    #     Linux with SQL Server Web` \| `Red Hat Enterprise Linux with SQL
+    #     Server Enterprise` \| `SQL Server Enterprise` \| `SQL Server
+    #     Standard` \| `SQL Server Web` \| `SUSE Linux` \| `Ubuntu Pro` \|
+    #     `Windows` \| `Windows BYOL` \| `Windows with SQL Server Enterprise`
+    #     \| `Windows with SQL Server Standard` \| `Windows with SQL Server
+    #     Web`).
     #
     #   * `private-dns-name` - The private IPv4 DNS name of the instance.
     #
